@@ -42,17 +42,15 @@ class UninstallApp(BaseApp):
         if args.uninstall_all_deps:
             uninstallGrafana = True
             uninstallIBMCatalog = True
-            uninstallCommonServices = True
             uninstallCertManager = True
-            uninstallUDS = True
+            uninstallDRO = True
             uninstallMongoDb = True
             uninstallSLS = True
         else:
             uninstallGrafana = args.uninstall_grafana
             uninstallIBMCatalog = args.uninstall_ibm_catalog
-            uninstallCommonServices = args.uninstall_common_services
             uninstallCertManager = args.uninstall_cert_manager
-            uninstallUDS = args.uninstall_uds
+            uninstallDRO = args.uninstall_dro
             uninstallMongoDb = args.uninstall_mongodb
             uninstallSLS = args.uninstall_sls
 
@@ -97,8 +95,7 @@ class UninstallApp(BaseApp):
                 # If you choose to uninstall Cert-Manager, everything will be uninstalled
                 uninstallGrafana = True
                 uninstallIBMCatalog = True
-                uninstallCommonServices = True
-                uninstallUDS = True
+                uninstallDRO = True
                 uninstallMongoDb = True
                 uninstallSLS = True
             else:
@@ -115,12 +112,10 @@ class UninstallApp(BaseApp):
                 uninstallIBMCatalog = self.yesOrNo("Uninstall IBM operator Catalog")
                 if uninstallIBMCatalog:
                     # If you choose to uninstall IBM Operator Catalog, everything from the catalog will be uninstalled
-                    uninstallCommonServices = True
-                    uninstallUDS = True
+                    uninstallDRO = True
                     uninstallSLS = True
                 else:
-                    uninstallCommonServices = self.yesOrNo("Uninstall IBM Common Services")
-                    uninstallUDS = self.yesOrNo("Uninstall IBM User Data Services")
+                    uninstallDRO = self.yesOrNo("Uninstall IBM Data Reporter Operator")
 
         else:
             # Non-interactive mode
@@ -148,8 +143,7 @@ class UninstallApp(BaseApp):
         self.printSummary("Uninstall Cert-Manager", f"{uninstallCertManager} ({certManagerProvider})")
         self.printSummary("Uninstall Grafana", uninstallGrafana)
         self.printSummary("Uninstall IBM Operator Catalog", uninstallIBMCatalog)
-        self.printSummary("Uninstall IBM Common Services", uninstallCommonServices)
-        self.printSummary("Uninstall UDS", uninstallUDS)
+        self.printSummary("Uninstall DRO", uninstallDRO)
         self.printSummary("Uninstall MongoDb", uninstallMongoDb)
         self.printSummary("Uninstall SLS", uninstallSLS)
 
@@ -182,12 +176,10 @@ class UninstallApp(BaseApp):
                 pipelineURL = launchUninstallPipeline(
                     dynClient=self.dynamicClient,
                     instanceId=instanceId,
-                    certManagerProvider="redhat",
                     uninstallCertManager=uninstallCertManager,
                     uninstallGrafana=uninstallGrafana,
-                    uninstallCatalog=uninstallCommonServices,
-                    uninstallCommonServices=uninstallCommonServices,
-                    uninstallUDS=uninstallUDS,
+                    uninstallCatalog=uninstallIBMCatalog,
+                    uninstallDRO=uninstallDRO,
                     uninstallMongoDb=uninstallMongoDb,
                     uninstallSLS=uninstallSLS,
                     droNamespace=droNamespace
