@@ -18,10 +18,9 @@ from prompt_toolkit import print_formatted_text, HTML
 from openshift.dynamic.exceptions import NotFoundError, ResourceNotFoundError
 
 from ..cli import BaseApp
-from ..validators import StorageClassValidator
 from .argParser import updateArgParser
-
-from mas.devops.ocp import createNamespace, getStorageClasses, getConsoleURL
+from mas.devops.data import getCatalog
+from mas.devops.ocp import createNamespace, getConsoleURL, getClusterVersion, isClusterVersionInRange
 from mas.devops.mas import listMasInstances, listAiServiceInstances, getCurrentCatalog
 from mas.devops.tekton import preparePipelinesNamespace, installOpenShiftPipelines, updateTektonDefinitions, launchUpdatePipeline
 
@@ -49,9 +48,9 @@ class UpdateApp(BaseApp):
                 "mongodb_v5_upgrade",
                 "mongodb_v6_upgrade",
                 "mongodb_v7_upgrade",
+                "mongodb_v8_upgrade",
                 "kafka_namespace",
                 "kafka_provider",
-                "dro_migration",
                 "dro_storage_class",
                 "dro_namespace",
                 "skip_pre_check",
@@ -137,7 +136,6 @@ class UpdateApp(BaseApp):
             else:
                 h.stop_and_persist(symbol=self.successIcon, text="IBM Certificate-Manager is not installed")
 
-        self.detectUDS()
         self.detectGrafana4()
         self.detectMongoDb()
         self.detectDb2uOrKafka("db2")
@@ -179,7 +177,6 @@ class UpdateApp(BaseApp):
 
         self.printH2("Required Migrations")
         self.printSummary("IBM Certificate-Manager", "Migrate to Red Hat Certificate-Manager" if self.getParam("cert_manager_action") != "" else "No action required")
-        self.printSummary("IBM User Data Services", "Migrate to IBM Data Reporter Operator" if self.getParam("dro_migration") != "" else "No action required")
         self.printSummary("Grafana v4 Operator", "Migrate to Grafana v5 Operator" if self.getParam("grafana_v5_upgrade") != "" else "No action required")
 
         if not self.noConfirm:
@@ -268,6 +265,14 @@ class UpdateApp(BaseApp):
         self.promptForListSelect("Select catalog version", catalogOptions, "mas_catalog_version", default=1)
 
     def validateCatalog(self) -> None:
+        # Check supported OCP versions
+        ocpVersion = getClusterVersion(self.dynamicClient)
+        # Load the catalog information
+        self.chosenCatalog = getCatalog(self.getParam("mas_catalog_version"))
+        supportedReleases = self.chosenCatalog.get("ocp_compatibility", [])
+        if len(supportedReleases) > 0 and not isClusterVersionInRange(ocpVersion, supportedReleases):
+            self.fatalError(f"IBM Maximo Operator Catalog {self.getParam('mas_catalog_version')} is not compatible with OpenShift v{ocpVersion}.  Compatible OpenShift releases are {supportedReleases}")
+
         if self.installedCatalogId is not None and self.installedCatalogId > self.getParam("mas_catalog_version"):
             self.fatalError(f"Selected catalog is older than the currently installed catalog.  Unable to update catalog from {self.installedCatalogId} to {self.getParam('mas_catalog_version')}")
 
@@ -441,67 +446,6 @@ class UpdateApp(BaseApp):
             ""
         ])
 
-    def showUDSUpdateNotice(self) -> None:
-        self.printHighlight([
-            "",
-            "<u>Dependency Update Notice</u>",
-            "IBM User Data Services (UDS) is currently installed and will be replaced by IBM Data Reporter Operator (DRO)",
-            "UDS will be uninstalled and <u>all MAS instances</u> will be re-configured to use DRO",
-            ""
-        ])
-
-    def selectDROStorageclass(self):
-        self.printDescription([
-            "",
-            "Select the storage class for DRO to use from the list below:"
-        ])
-        for storageClass in getStorageClasses(self.dynamicClient):
-            print_formatted_text(HTML(f"<LightSlateGrey>  - {storageClass.metadata.name}</LightSlateGrey>"))
-        self.promptForString("DRO storage class", "dro_storage_class", validator=StorageClassValidator())
-
-    def detectUDS(self) -> None:
-        with Halo(text='Checking for IBM User Data Services', spinner=self.spinner) as h:
-            try:
-                analyticsProxyAPI = self.dynamicClient.resources.get(api_version="uds.ibm.com/v1", kind="AnalyticsProxy")
-                analyticsProxies = analyticsProxyAPI.get(namespace="ibm-common-services").to_dict()['items']
-
-                # Useful for testing: comment out the two lines above and set analyticsProxies to a
-                # simple list to trigger to UDS migration logic.
-                # analyticsProxies = ["foo"]
-                if len(analyticsProxies) == 0:
-                    logger.debug("UDS is not currently installed on this cluster")
-                    h.stop_and_persist(symbol=self.successIcon, text="IBM User Data Services is not installed")
-                else:
-                    h.stop_and_persist(symbol=self.successIcon, text="IBM User Data Services must be migrated to IBM Data Reporter Operator")
-
-                    if self.noConfirm and self.getParam("dro_migration") != "true":
-                        # The user has chosen not to provide confirmation but has not provided the flag to pre-approve the migration
-                        h.stop_and_persist(symbol=self.failureIcon, text="IBM User Data Services needs to be migrated to IBM Data Reporter Operator")
-                        self.showUDSUpdateNotice()
-                        self.fatalError(f"By choosing {self.getParam('mas_catalog_version')} you must confirm the migration to DRO using '--dro-migration' when using '--no-confirm'")
-                    elif self.noConfirm and self.getParam("dro_storage_class") is None:
-                        # The user has not provided the storage class to use for DRO, but has disabled confirmations/interactive prompts
-                        h.stop_and_persist(symbol=self.failureIcon, text="IBM User Data Services needs to be migrated to IBM Data Reporter Operator")
-                        self.showUDSUpdateNotice()
-                        self.fatalError(f"By choosing {self.getParam('mas_catalog_version')} you must provide the storage class to use for the migration to DRO using '--dro-storage-class' when using '--no-confirm'")
-                    else:
-                        self.showUDSUpdateNotice()
-                        if self.getParam("dro_migration") != "true":
-                            if not self.yesOrNo("Confirm migration from UDS to DRO", "dro_migration"):
-                                # If the user did not approve the update, abort
-                                exit(1)
-
-                        if self.getParam("dro_storage_class") is None or self.getParam("dro_storage_class") == "":
-                            self.selectDROStorageclass()
-
-                if self.getParam("dro_migration") == "true":
-                    self.setParam("uds_action", "install-dro")
-
-            except (ResourceNotFoundError, NotFoundError):
-                # UDS has never been installed on this cluster
-                logger.debug("UDS has not been installed on this cluster before")
-                h.stop_and_persist(symbol=self.successIcon, text="IBM User Data Services is not installed")
-
     def detectCP4D(self) -> bool:
         # Important:
         # This CLI can run independent of the ibm.mas_devops collection, so we cannot reference
@@ -597,8 +541,6 @@ class UpdateApp(BaseApp):
                         self.detectCpdService('WS', 'ws.cpd.ibm.com/v1beta1', 'Watson Studio', "cp4d_update_ws")
                         self.detectCpdService('WmlBase', 'wml.cpd.ibm.com/v1beta1', 'Watson Machine Learning', "cp4d_update_wml")
                         self.detectCpdService('AnalyticsEngine', 'ae.cpd.ibm.com/v1', 'Analytics Engine', "cp4d_update_spark")
-                        self.detectCpdService('WOService', 'wos.cpd.ibm.com/v1', 'Watson Openscale', "cp4d_update_wos")
-                        self.detectCpdService('Spss', 'spssmodeler.cpd.ibm.com/v1', 'SPSS Modeler', "cp4d_update_spss")
                         self.detectCpdService('CAService', 'ca.cpd.ibm.com/v1', 'Cognos Analytics', "cp4d_update_cognos")
                     else:
                         h.stop_and_persist(symbol=self.successIcon, text=f"IBM Cloud Pak for Data ({cpdInstanceNamespace}) is already installed at version {cpdTargetVersion}")
